@@ -2,9 +2,10 @@
 
 from typing import List, Optional, Set, Union
 
-from pydantic import Field
+from pydantic import Field, validator
 
-from jade.models import JadeBaseModel, HpcConfig
+from jade.enums import ResourceMonitorType
+from jade.models import JadeBaseModel, HpcConfig, SingularityParams
 
 
 class SubmitterParams(JadeBaseModel):
@@ -51,8 +52,14 @@ class SubmitterParams(JadeBaseModel):
     )
     resource_monitor_interval: Optional[int] = Field(
         title="resource_monitor_interval",
-        description="Interval in seconds on which to collect resource stats",
-        default=None,
+        description="Interval in seconds on which to collect resource stats. If None, aggregate"
+        "summaries of stats.",
+        default=1,
+    )
+    resource_monitor_type: Optional[ResourceMonitorType] = Field(
+        title="resource_monitor_type",
+        description=f"Type of resource monitoring to perform. Options: {list(ResourceMonitorType)}",
+        default=ResourceMonitorType.AGGREGATION,
     )
     try_add_blocked_jobs: Optional[bool] = Field(
         title="try_add_blocked_jobs",
@@ -75,3 +82,8 @@ class SubmitterParams(JadeBaseModel):
         description="Enable debug logging",
         default=False,
     )
+    singularity_params: Optional[SingularityParams] = Field(
+        title="singularity_params",
+        description="Singularity container parameters",
+        default=None,
+    )
